<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Xs_Fun_Fact_Widget extends Widget_Base {

    public function get_name() {
        return 'xs-fun-fact';
    }

    public function get_title() {
        return esc_html__( 'Geobin Fun Fact', 'geobin' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return [ 'geobin-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Fun fact', 'geobin'),
            ]
        );

        $this->add_control(

            'fun_fact_style', [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Choose Style', 'geobin'),
                'default' => 'style1',
                'options' => [
                    'style1' => esc_html__('Style 1', 'geobin'),
                    'style2' => esc_html__('Style 2', 'geobin'),
                    'style3' => esc_html__('Style 3', 'geobin'),
                ],
            ]
        );

        $this->add_control(

            'fact_name', [

                'label' => esc_html__('Title', 'geobin'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default'   => esc_html__('Add a title ', 'geobin'),
            ]
        );

        $this->add_control(

            'fact_value',
            [

                'label' => esc_html__('Value', 'geobin'),
                'type' => Controls_Manager::NUMBER,
                'default'    => esc_html__('4000', 'geobin'),
                'label_block' => true,
                'condition'     => [
                    'fun_fact_style' => ['style1', 'style3']
                ]
            ]
        );

        $this->add_control(

            'fun_fact_attribute',
            [
                'label' => esc_html__('Attribute', 'geobin'),
                'description' => esc_html__('You can put here + or %', 'geobin'),
                'type' => Controls_Manager::TEXT,
                'default'    => esc_html__('+', 'geobin'),
            ]
        );

        $this->add_control(
            'fun_fact_image',
            [
                'label' => esc_html__('Image', 'geobin'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => GEOBIN_IMAGES_DIR_URI . '/cases/service_04.png',
                ]
        ]
        );

        $this->add_control(
            'fun_fact_image_margin',
            [
                'label' => esc_html__('Image', 'geobin'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .facts-img img' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'fun_fact_style' => ['style1']
                ]
        ]
        );

        $this->add_control(
            'total_percentage',
            [
                'label' => esc_html__( 'Total Parcentage', 'geobin' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 96,
                'condition' => [
                    'fun_fact_style'   =>  ['style2'],
                ],

            ]
        );

        $this->add_control(
            'total_amount',
            [
                'label' => esc_html__( 'Total Amount', 'geobin' ),
                'type' => Controls_Manager::TEXT,
                'default' => '899 of 1203',
                'condition' => [
                    'fun_fact_style'   =>  ['style2'],
                ],

            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'chart_title_color',
            [
                'label' => esc_html__('Title Styles', 'geobin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'geobin' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .percent-area > p ' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .tw-traffic-counter h3 ' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'chart_title_typography',
                'label' => esc_html__( 'Typography', 'geobin' ),
                'selectors' => [
                    '{{WRAPPER}} .percent-area > p',
                    '{{WRAPPER}} .tw-traffic-counter h3'
                ]
            ]
        );

        $this->end_controls_section();

    }

    protected function render( ) {

        $settings = $this->get_settings();
        $fun_fact_style = $settings['fun_fact_style'];

        $fact_name = $settings['fact_name'];
        $fact_value = $settings['fact_value'];
        $fun_fact_attribute = $settings['fun_fact_attribute'];
        $fun_fact_image = $settings['fun_fact_image'];

        /*Style 2*/
        $total_percentage = $settings['total_percentage'];
        $total_amount = $settings['total_amount'];

        switch ($fun_fact_style){
            case 'style1':
                require GEOBIN_SHORTCODE_DIR_STYLE .'/fun-facts/style1.php';
                break;

            case 'style2':
                require GEOBIN_SHORTCODE_DIR_STYLE .'/fun-facts/style2.php';
                break;

            case 'style3':
                require GEOBIN_SHORTCODE_DIR_STYLE .'/fun-facts/style3.php';
                break;
        }
    }

    protected function _content_template() { }
}