<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Xs_Services_Widget extends Widget_Base {

    public function get_name() {
        return 'xs-services';
    }

    public function get_title() {
        return esc_html__( 'Geobin Services', 'geobin' );
    }

    public function get_icon() {
        return 'fa fa-folder-open';
    }

    public function get_categories() {
        return [ 'geobin-elements' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Geobin Service', 'geobin'),
            ]
        );

        $this->add_control(

            'service_style', [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Choose Style', 'geobin'),
                'default' => 'style1',
                'options' => [
                    'style1' => esc_html__('Style 1', 'geobin'),
                    'style2' => esc_html__('Service Carousel', 'geobin'),
                ],
            ]
        );
    
		$this->add_control(
	      'post_count',
	      [
	        'label'         => esc_html__( 'Post count', 'geobin' ),
	        'type'          => Controls_Manager::NUMBER,
	        'default'       => 6,
            'condition'     => ['service_style' => 'style1']
	      ]
	    );

        $this->add_control(
            'title_text', [
                'label'			 => esc_html__( 'Heading Title', 'geobin' ),
                'type'			 => Controls_Manager::TEXT,
                'label_block'	 => true,
                'placeholder'	 => esc_html__( 'Add title here', 'geobin' ),
                'default'        => esc_html__( 'Add a title here', 'geobin'),
                'condition'     => ['service_style' => 'style2']
            ]
        );

        $this->add_control(
            'title_text_desc', [
                'label'			 => esc_html__( 'Heading Description', 'geobin' ),
                'type'			 => Controls_Manager::TEXTAREA,
                'label_block'	 => true,
                'placeholder'	 => esc_html__( 'Add some text here', 'geobin' ),
                'default'        => esc_html__( 'Start working with an company that can provide everything you need to generate awareness, drive traffic, connect with customers, and increase sales montes, 
nascetur ridiculus mus.', 'geobin'),
                'condition'      => [
                    'service_style'     => 'style2'
                ]
            ]
        );
		$this->add_control(
			'border_color', [
				'label'		 => esc_html__( 'Border Color', 'geobin' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} .section-heading span.animate-border' => 'background: {{VALUE}};',
				],
				'condition'      => [
                    'service_style'     => 'style2'
                ]
			]
		);

		$this->add_control(
			'animate_border_color', [
				'label'		 => esc_html__( 'Animated Border Color', 'geobin' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} .animate-border:after' => 'border-right-color: {{VALUE}}; border-left-color: {{VALUE}};',
				],
				'condition'      => [
                    'service_style'     => 'style2'
                ]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
            'section_genarel_styling',
            [
                'label' => esc_html__('General Setting', 'geobin'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

		$this->add_control(
            'gutter',
            [
                'label' => esc_html__('Gutter', 'geobin'),
                'description' => esc_html__('Space between columns in the grid.', 'geobin'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .geobin-photo-gallery-grid-v3-item' => 'padding: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .geobin-photo-gallery-grid-item' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

	}
    protected function render( ) {

        $settings = $this->get_settings();

        $post_count = $settings['post_count'];
        $service_style = $settings['service_style'];
        $title = $settings[ 'title_text' ];
        $title_desc = $settings[ 'title_text_desc' ];

        switch ($service_style) {

            case 'style1':
                require GEOBIN_SHORTCODE_DIR_STYLE .'/service/style1.php';
                break;

            case 'style2':
                require GEOBIN_SHORTCODE_DIR_STYLE .'/service/style2.php';
                break;
        }

    }

    protected function _content_template() { }
}
?>